/**
 * @file
 * VuoList_VuoBoolean C type definition.
 *
 * @copyright Copyright © 2012–2013 Kosada Incorporated.
 * This code may be modified and distributed under the terms of the MIT License.
 * For more information, see http://vuo.org/license.
 */

#ifndef VuoList_VuoBoolean_H
#define VuoList_VuoBoolean_H

/**
 * @ingroup VuoTypes
 * @defgroup VuoList_VuoBoolean VuoList_VuoBoolean
 * A list of @ref VuoBoolean elements.
 *
 * @{
 */

// This header is generated by vuo/type/list/generateVariants.sh.

/**
 * @typedef VuoList_VuoBoolean
 * A list of @ref VuoBoolean elements.
 */
#ifndef VuoList_VuoBoolean_TYPE_DEFINED
typedef void * VuoList_VuoBoolean;
#endif

/**
 * Creates a new list of @ref VuoBoolean elements.
 */
VuoList_VuoBoolean VuoListCreate_VuoBoolean(void);

/**
 * Returns the @ref VuoBoolean at @c index.
 * Index values start at 1.
 * If the list has no items, returns a default value.
 * Attempting to access an out-of-bounds index returns the first item in the list (if the index is 0), or last item in the list (if the index is greater than the list size).
 */
VuoBoolean VuoListGetValueAtIndex_VuoBoolean(const VuoList_VuoBoolean list, const unsigned long index);

/**
 * Appends @c value to @c list.
 */
void VuoListAppendValue_VuoBoolean(VuoList_VuoBoolean list, const VuoBoolean value);

/**
 * Removes the last value from @c list.
 */
void VuoListRemoveLastValue_VuoBoolean(VuoList_VuoBoolean list);

/**
 * Removes all values from @c list.
 */
void VuoListRemoveAll_VuoBoolean(VuoList_VuoBoolean list);

/**
 * Returns the number of elements in @c list.
 */
unsigned long VuoListGetCount_VuoBoolean(const VuoList_VuoBoolean list);

/**
 * Decodes the JSON object @c js to create a new value.
 *
 * @eg{
 *	["uno", "dos", "tres", "catorce"]
 * }
 */
VuoList_VuoBoolean VuoList_VuoBoolean_valueFromJson(struct json_object * js);

/**
 * Encodes @c value as a JSON object.
 */
struct json_object * VuoList_VuoBoolean_jsonFromValue(const VuoList_VuoBoolean value);

/**
 * Produces a brief human-readable summary of @c value.
 */
char * VuoList_VuoBoolean_summaryFromValue(const VuoList_VuoBoolean value);

/// @{
/**
 * Automatically generated function.
 */
VuoList_VuoBoolean VuoList_VuoBoolean_valueFromString(const char *str);
char * VuoList_VuoBoolean_stringFromValue(const VuoList_VuoBoolean value);
/// @}

/**
 * @}
 */

#endif
