/**
 * @file
 * VuoList_VuoImage C type definition.
 *
 * @copyright Copyright © 2012–2013 Kosada Incorporated.
 * This code may be modified and distributed under the terms of the MIT License.
 * For more information, see http://vuo.org/license.
 */

#ifndef VuoList_VuoImage_H
#define VuoList_VuoImage_H

/**
 * @ingroup VuoTypes
 * @defgroup VuoList_VuoImage VuoList_VuoImage
 * A list of @ref VuoImage elements.
 *
 * @{
 */

// This header is generated by vuo/type/list/generateVariants.sh.

/**
 * @typedef VuoList_VuoImage
 * A list of @ref VuoImage elements.
 */
#ifndef VuoList_VuoImage_TYPE_DEFINED
typedef void * VuoList_VuoImage;
#endif

/**
 * Creates a new list of @ref VuoImage elements.
 */
VuoList_VuoImage VuoListCreate_VuoImage(void);

/**
 * Returns the @ref VuoImage at @c index.
 * Index values start at 1.
 * If the list has no items, returns a default value.
 * Attempting to access an out-of-bounds index returns the first item in the list (if the index is 0), or last item in the list (if the index is greater than the list size).
 */
VuoImage VuoListGetValueAtIndex_VuoImage(const VuoList_VuoImage list, const unsigned long index);

/**
 * Appends @c value to @c list.
 */
void VuoListAppendValue_VuoImage(VuoList_VuoImage list, const VuoImage value);

/**
 * Removes the last value from @c list.
 */
void VuoListRemoveLastValue_VuoImage(VuoList_VuoImage list);

/**
 * Removes all values from @c list.
 */
void VuoListRemoveAll_VuoImage(VuoList_VuoImage list);

/**
 * Returns the number of elements in @c list.
 */
unsigned long VuoListGetCount_VuoImage(const VuoList_VuoImage list);

/**
 * Decodes the JSON object @c js to create a new value.
 *
 * @eg{
 *	["uno", "dos", "tres", "catorce"]
 * }
 */
VuoList_VuoImage VuoList_VuoImage_valueFromJson(struct json_object * js);

/**
 * Encodes @c value as a JSON object.
 */
struct json_object * VuoList_VuoImage_jsonFromValue(const VuoList_VuoImage value);

/**
 * Produces a brief human-readable summary of @c value.
 */
char * VuoList_VuoImage_summaryFromValue(const VuoList_VuoImage value);

/// @{
/**
 * Automatically generated function.
 */
VuoList_VuoImage VuoList_VuoImage_valueFromString(const char *str);
char * VuoList_VuoImage_stringFromValue(const VuoList_VuoImage value);
/// @}

/**
 * @}
 */

#endif
