/**
 * @file
 * VuoList_VuoPoint3d C type definition.
 *
 * @copyright Copyright © 2012–2013 Kosada Incorporated.
 * This code may be modified and distributed under the terms of the MIT License.
 * For more information, see http://vuo.org/license.
 */

#ifndef VuoList_VuoPoint3d_H
#define VuoList_VuoPoint3d_H

/**
 * @ingroup VuoTypes
 * @defgroup VuoList_VuoPoint3d VuoList_VuoPoint3d
 * A list of @ref VuoPoint3d elements.
 *
 * @{
 */

// This header is generated by vuo/type/list/generateVariants.sh.

/**
 * @typedef VuoList_VuoPoint3d
 * A list of @ref VuoPoint3d elements.
 */
#ifndef VuoList_VuoPoint3d_TYPE_DEFINED
typedef void * VuoList_VuoPoint3d;
#endif

/**
 * Creates a new list of @ref VuoPoint3d elements.
 */
VuoList_VuoPoint3d VuoListCreate_VuoPoint3d(void);

/**
 * Returns the @ref VuoPoint3d at @c index.
 * Index values start at 1.
 * If the list has no items, returns a default value.
 * Attempting to access an out-of-bounds index returns the first item in the list (if the index is 0), or last item in the list (if the index is greater than the list size).
 */
VuoPoint3d VuoListGetValueAtIndex_VuoPoint3d(const VuoList_VuoPoint3d list, const unsigned long index);

/**
 * Appends @c value to @c list.
 */
void VuoListAppendValue_VuoPoint3d(VuoList_VuoPoint3d list, const VuoPoint3d value);

/**
 * Removes the last value from @c list.
 */
void VuoListRemoveLastValue_VuoPoint3d(VuoList_VuoPoint3d list);

/**
 * Removes all values from @c list.
 */
void VuoListRemoveAll_VuoPoint3d(VuoList_VuoPoint3d list);

/**
 * Returns the number of elements in @c list.
 */
unsigned long VuoListGetCount_VuoPoint3d(const VuoList_VuoPoint3d list);

/**
 * Decodes the JSON object @c js to create a new value.
 *
 * @eg{
 *	["uno", "dos", "tres", "catorce"]
 * }
 */
VuoList_VuoPoint3d VuoList_VuoPoint3d_valueFromJson(struct json_object * js);

/**
 * Encodes @c value as a JSON object.
 */
struct json_object * VuoList_VuoPoint3d_jsonFromValue(const VuoList_VuoPoint3d value);

/**
 * Produces a brief human-readable summary of @c value.
 */
char * VuoList_VuoPoint3d_summaryFromValue(const VuoList_VuoPoint3d value);

/// @{
/**
 * Automatically generated function.
 */
VuoList_VuoPoint3d VuoList_VuoPoint3d_valueFromString(const char *str);
char * VuoList_VuoPoint3d_stringFromValue(const VuoList_VuoPoint3d value);
/// @}

/**
 * @}
 */

#endif
