/**
 * @file
 * VuoList_VuoPoint4d C type definition.
 *
 * @copyright Copyright © 2012–2013 Kosada Incorporated.
 * This code may be modified and distributed under the terms of the MIT License.
 * For more information, see http://vuo.org/license.
 */

#ifndef VuoList_VuoPoint4d_H
#define VuoList_VuoPoint4d_H

/**
 * @ingroup VuoTypes
 * @defgroup VuoList_VuoPoint4d VuoList_VuoPoint4d
 * A list of @ref VuoPoint4d elements.
 *
 * @{
 */

// This header is generated by vuo/type/list/generateVariants.sh.

/**
 * @typedef VuoList_VuoPoint4d
 * A list of @ref VuoPoint4d elements.
 */
#ifndef VuoList_VuoPoint4d_TYPE_DEFINED
typedef void * VuoList_VuoPoint4d;
#endif

/**
 * Creates a new list of @ref VuoPoint4d elements.
 */
VuoList_VuoPoint4d VuoListCreate_VuoPoint4d(void);

/**
 * Returns the @ref VuoPoint4d at @c index.
 * Index values start at 1.
 * If the list has no items, returns a default value.
 * Attempting to access an out-of-bounds index returns the first item in the list (if the index is 0), or last item in the list (if the index is greater than the list size).
 */
VuoPoint4d VuoListGetValueAtIndex_VuoPoint4d(const VuoList_VuoPoint4d list, const unsigned long index);

/**
 * Appends @c value to @c list.
 */
void VuoListAppendValue_VuoPoint4d(VuoList_VuoPoint4d list, const VuoPoint4d value);

/**
 * Removes the last value from @c list.
 */
void VuoListRemoveLastValue_VuoPoint4d(VuoList_VuoPoint4d list);

/**
 * Removes all values from @c list.
 */
void VuoListRemoveAll_VuoPoint4d(VuoList_VuoPoint4d list);

/**
 * Returns the number of elements in @c list.
 */
unsigned long VuoListGetCount_VuoPoint4d(const VuoList_VuoPoint4d list);

/**
 * Decodes the JSON object @c js to create a new value.
 *
 * @eg{
 *	["uno", "dos", "tres", "catorce"]
 * }
 */
VuoList_VuoPoint4d VuoList_VuoPoint4d_valueFromJson(struct json_object * js);

/**
 * Encodes @c value as a JSON object.
 */
struct json_object * VuoList_VuoPoint4d_jsonFromValue(const VuoList_VuoPoint4d value);

/**
 * Produces a brief human-readable summary of @c value.
 */
char * VuoList_VuoPoint4d_summaryFromValue(const VuoList_VuoPoint4d value);

/// @{
/**
 * Automatically generated function.
 */
VuoList_VuoPoint4d VuoList_VuoPoint4d_valueFromString(const char *str);
char * VuoList_VuoPoint4d_stringFromValue(const VuoList_VuoPoint4d value);
/// @}

/**
 * @}
 */

#endif
