/**
 * @file
 * VuoList_VuoReal C type definition.
 *
 * @copyright Copyright © 2012–2013 Kosada Incorporated.
 * This code may be modified and distributed under the terms of the MIT License.
 * For more information, see http://vuo.org/license.
 */

#ifndef VuoList_VuoReal_H
#define VuoList_VuoReal_H

/**
 * @ingroup VuoTypes
 * @defgroup VuoList_VuoReal VuoList_VuoReal
 * A list of @ref VuoReal elements.
 *
 * @{
 */

// This header is generated by vuo/type/list/generateVariants.sh.

/**
 * @typedef VuoList_VuoReal
 * A list of @ref VuoReal elements.
 */
#ifndef VuoList_VuoReal_TYPE_DEFINED
typedef void * VuoList_VuoReal;
#endif

/**
 * Creates a new list of @ref VuoReal elements.
 */
VuoList_VuoReal VuoListCreate_VuoReal(void);

/**
 * Returns the @ref VuoReal at @c index.
 * Index values start at 1.
 * If the list has no items, returns a default value.
 * Attempting to access an out-of-bounds index returns the first item in the list (if the index is 0), or last item in the list (if the index is greater than the list size).
 */
VuoReal VuoListGetValueAtIndex_VuoReal(const VuoList_VuoReal list, const unsigned long index);

/**
 * Appends @c value to @c list.
 */
void VuoListAppendValue_VuoReal(VuoList_VuoReal list, const VuoReal value);

/**
 * Removes the last value from @c list.
 */
void VuoListRemoveLastValue_VuoReal(VuoList_VuoReal list);

/**
 * Removes all values from @c list.
 */
void VuoListRemoveAll_VuoReal(VuoList_VuoReal list);

/**
 * Returns the number of elements in @c list.
 */
unsigned long VuoListGetCount_VuoReal(const VuoList_VuoReal list);

/**
 * Decodes the JSON object @c js to create a new value.
 *
 * @eg{
 *	["uno", "dos", "tres", "catorce"]
 * }
 */
VuoList_VuoReal VuoList_VuoReal_valueFromJson(struct json_object * js);

/**
 * Encodes @c value as a JSON object.
 */
struct json_object * VuoList_VuoReal_jsonFromValue(const VuoList_VuoReal value);

/**
 * Produces a brief human-readable summary of @c value.
 */
char * VuoList_VuoReal_summaryFromValue(const VuoList_VuoReal value);

/// @{
/**
 * Automatically generated function.
 */
VuoList_VuoReal VuoList_VuoReal_valueFromString(const char *str);
char * VuoList_VuoReal_stringFromValue(const VuoList_VuoReal value);
/// @}

/**
 * @}
 */

#endif
