/**
 * @file
 * VuoList_VuoSceneObject C type definition.
 *
 * @copyright Copyright © 2012–2013 Kosada Incorporated.
 * This code may be modified and distributed under the terms of the MIT License.
 * For more information, see http://vuo.org/license.
 */

#ifndef VuoList_VuoSceneObject_H
#define VuoList_VuoSceneObject_H

/**
 * @ingroup VuoTypes
 * @defgroup VuoList_VuoSceneObject VuoList_VuoSceneObject
 * A list of @ref VuoSceneObject elements.
 *
 * @{
 */

// This header is generated by vuo/type/list/generateVariants.sh.

/**
 * @typedef VuoList_VuoSceneObject
 * A list of @ref VuoSceneObject elements.
 */
#ifndef VuoList_VuoSceneObject_TYPE_DEFINED
typedef void * VuoList_VuoSceneObject;
#endif

/**
 * Creates a new list of @ref VuoSceneObject elements.
 */
VuoList_VuoSceneObject VuoListCreate_VuoSceneObject(void);

/**
 * Returns the @ref VuoSceneObject at @c index.
 * Index values start at 1.
 * If the list has no items, returns a default value.
 * Attempting to access an out-of-bounds index returns the first item in the list (if the index is 0), or last item in the list (if the index is greater than the list size).
 */
VuoSceneObject VuoListGetValueAtIndex_VuoSceneObject(const VuoList_VuoSceneObject list, const unsigned long index);

/**
 * Appends @c value to @c list.
 */
void VuoListAppendValue_VuoSceneObject(VuoList_VuoSceneObject list, const VuoSceneObject value);

/**
 * Removes the last value from @c list.
 */
void VuoListRemoveLastValue_VuoSceneObject(VuoList_VuoSceneObject list);

/**
 * Removes all values from @c list.
 */
void VuoListRemoveAll_VuoSceneObject(VuoList_VuoSceneObject list);

/**
 * Returns the number of elements in @c list.
 */
unsigned long VuoListGetCount_VuoSceneObject(const VuoList_VuoSceneObject list);

/**
 * Decodes the JSON object @c js to create a new value.
 *
 * @eg{
 *	["uno", "dos", "tres", "catorce"]
 * }
 */
VuoList_VuoSceneObject VuoList_VuoSceneObject_valueFromJson(struct json_object * js);

/**
 * Encodes @c value as a JSON object.
 */
struct json_object * VuoList_VuoSceneObject_jsonFromValue(const VuoList_VuoSceneObject value);

/**
 * Produces a brief human-readable summary of @c value.
 */
char * VuoList_VuoSceneObject_summaryFromValue(const VuoList_VuoSceneObject value);

/// @{
/**
 * Automatically generated function.
 */
VuoList_VuoSceneObject VuoList_VuoSceneObject_valueFromString(const char *str);
char * VuoList_VuoSceneObject_stringFromValue(const VuoList_VuoSceneObject value);
/// @}

/**
 * @}
 */

#endif
