/**
 * @file
 * VuoList_VuoText C type definition.
 *
 * @copyright Copyright © 2012–2013 Kosada Incorporated.
 * This code may be modified and distributed under the terms of the MIT License.
 * For more information, see http://vuo.org/license.
 */

#ifndef VuoList_VuoText_H
#define VuoList_VuoText_H

/**
 * @ingroup VuoTypes
 * @defgroup VuoList_VuoText VuoList_VuoText
 * A list of @ref VuoText elements.
 *
 * @{
 */

// This header is generated by vuo/type/list/generateVariants.sh.

/**
 * @typedef VuoList_VuoText
 * A list of @ref VuoText elements.
 */
#ifndef VuoList_VuoText_TYPE_DEFINED
typedef void * VuoList_VuoText;
#endif

/**
 * Creates a new list of @ref VuoText elements.
 */
VuoList_VuoText VuoListCreate_VuoText(void);

/**
 * Returns the @ref VuoText at @c index.
 * Index values start at 1.
 * If the list has no items, returns a default value.
 * Attempting to access an out-of-bounds index returns the first item in the list (if the index is 0), or last item in the list (if the index is greater than the list size).
 */
VuoText VuoListGetValueAtIndex_VuoText(const VuoList_VuoText list, const unsigned long index);

/**
 * Appends @c value to @c list.
 */
void VuoListAppendValue_VuoText(VuoList_VuoText list, const VuoText value);

/**
 * Removes the last value from @c list.
 */
void VuoListRemoveLastValue_VuoText(VuoList_VuoText list);

/**
 * Removes all values from @c list.
 */
void VuoListRemoveAll_VuoText(VuoList_VuoText list);

/**
 * Returns the number of elements in @c list.
 */
unsigned long VuoListGetCount_VuoText(const VuoList_VuoText list);

/**
 * Decodes the JSON object @c js to create a new value.
 *
 * @eg{
 *	["uno", "dos", "tres", "catorce"]
 * }
 */
VuoList_VuoText VuoList_VuoText_valueFromJson(struct json_object * js);

/**
 * Encodes @c value as a JSON object.
 */
struct json_object * VuoList_VuoText_jsonFromValue(const VuoList_VuoText value);

/**
 * Produces a brief human-readable summary of @c value.
 */
char * VuoList_VuoText_summaryFromValue(const VuoList_VuoText value);

/// @{
/**
 * Automatically generated function.
 */
VuoList_VuoText VuoList_VuoText_valueFromString(const char *str);
char * VuoList_VuoText_stringFromValue(const VuoList_VuoText value);
/// @}

/**
 * @}
 */

#endif
