/**
 * @file
 * VuoList_VuoVertices C type definition.
 *
 * @copyright Copyright © 2012–2013 Kosada Incorporated.
 * This code may be modified and distributed under the terms of the MIT License.
 * For more information, see http://vuo.org/license.
 */

#ifndef VuoList_VuoVertices_H
#define VuoList_VuoVertices_H

/**
 * @ingroup VuoTypes
 * @defgroup VuoList_VuoVertices VuoList_VuoVertices
 * A list of @ref VuoVertices elements.
 *
 * @{
 */

// This header is generated by vuo/type/list/generateVariants.sh.

/**
 * @typedef VuoList_VuoVertices
 * A list of @ref VuoVertices elements.
 */
#ifndef VuoList_VuoVertices_TYPE_DEFINED
typedef void * VuoList_VuoVertices;
#endif

/**
 * Creates a new list of @ref VuoVertices elements.
 */
VuoList_VuoVertices VuoListCreate_VuoVertices(void);

/**
 * Returns the @ref VuoVertices at @c index.
 * Index values start at 1.
 * If the list has no items, returns a default value.
 * Attempting to access an out-of-bounds index returns the first item in the list (if the index is 0), or last item in the list (if the index is greater than the list size).
 */
VuoVertices VuoListGetValueAtIndex_VuoVertices(const VuoList_VuoVertices list, const unsigned long index);

/**
 * Appends @c value to @c list.
 */
void VuoListAppendValue_VuoVertices(VuoList_VuoVertices list, const VuoVertices value);

/**
 * Removes the last value from @c list.
 */
void VuoListRemoveLastValue_VuoVertices(VuoList_VuoVertices list);

/**
 * Removes all values from @c list.
 */
void VuoListRemoveAll_VuoVertices(VuoList_VuoVertices list);

/**
 * Returns the number of elements in @c list.
 */
unsigned long VuoListGetCount_VuoVertices(const VuoList_VuoVertices list);

/**
 * Decodes the JSON object @c js to create a new value.
 *
 * @eg{
 *	["uno", "dos", "tres", "catorce"]
 * }
 */
VuoList_VuoVertices VuoList_VuoVertices_valueFromJson(struct json_object * js);

/**
 * Encodes @c value as a JSON object.
 */
struct json_object * VuoList_VuoVertices_jsonFromValue(const VuoList_VuoVertices value);

/**
 * Produces a brief human-readable summary of @c value.
 */
char * VuoList_VuoVertices_summaryFromValue(const VuoList_VuoVertices value);

/// @{
/**
 * Automatically generated function.
 */
VuoList_VuoVertices VuoList_VuoVertices_valueFromString(const char *str);
char * VuoList_VuoVertices_stringFromValue(const VuoList_VuoVertices value);
/// @}

/**
 * @}
 */

#endif
